@@ -1,8 +1,18 @@
 # Copyright 1999-2003 Gentoo Technologies, Inc.
 # Distributed under the terms of the GNU General Public License v2
-# $Header: /home/cvsroot/gentoo-src/rc-scripts/init.d/halt.sh,v 1.44 2003/11/10 00:29:47 azarah Exp $
+# $Header: /home/cvsroot/gentoo-src/rc-scripts/init.d/halt.sh,v 1.48 2004/02/08 11:02:20 azarah Exp $
 
 
+# Check to see if this is a livecd, if it is read the commandline
+# this mainly makes sure $CDBOOT is defined if it's a livecd
+[ -f "/sbin/livecd-functions.sh" ] && \
+	source /sbin/livecd-functions.sh && \
+	livecd_read_commandline
+
+# Reset pam_console permissions
+[ -x /sbin/pam_console_apply -a ! -c /dev/.devfsd ] && \
+	/sbin/pam_console_apply -r
+
 # We need to properly terminate devfsd to save the permissions
 if [ -n "`ps --no-heading -C 'devfsd'`" ]
 then
@@ -44,7 +54,8 @@ halt -w &>/dev/null
 # Unmount file systems, killing processes if we have to.
 # Unmount loopback stuff first
 # Use `umount -d` to detach the loopback device
-remaining="`awk '!/^#/ && $1 ~ /^\/dev\/loop/ && $2 != "/" {print $2}' /proc/mounts | sort -r`"
+remaining="`awk '!/^#/ && $1 ~ /^\/dev\/loop/ && $2 != "/" {print $2}' /proc/mounts | \
+            sort -r | grep -v '/newroot' | grep -v '/mnt/livecd'`"
 [ -n "${remaining}" ] && {
 	sig=
 	retry=3
@@ -62,7 +73,8 @@ remaining="`awk '!/^#/ && $1 ~ /^\/dev\/loop/ && $2 != "/" {print $2}' /proc/mou
 			eend $? "Failed to unmount filesystems"
 		fi
 		
-		remaining="`awk '!/^#/ && $1 ~ /^\/dev\/loop/ && $2 != "/" {print $2}' /proc/mounts | sort -r`"
+		remaining="`awk '!/^#/ && $1 ~ /^\/dev\/loop/ && $2 != "/" {print $2}' /proc/mounts | \
+		            sort -r | grep -v '/newroot' | grep -v '/mnt/livecd'`"
 		[ -z "${remaining}" ] && break
 		
 		/bin/fuser -k -m ${sig} ${remaining} &>/dev/null
@@ -76,25 +88,31 @@ remaining="`awk '!/^#/ && $1 ~ /^\/dev\/loop/ && $2 != "/" {print $2}' /proc/mou
 # This is needed to make sure we dont have a mounted filesystem
 # on a LVM volume when shutting LVM down ...
 ebegin "Unmounting filesystems"
-no_unmount="`mount | awk '{ if (($5 ~ /^(proc|sysfs|devfs|tmpfs|usb(dev)?fs)$/) ||
-                             ($1 ~ /^(rootfs|\/dev\/root)$/) ||
-                             ($3 = "/"))
+no_unmounts="`mount | awk '{ if (($5 ~ /^(proc|sysfs|devfs|tmpfs|usb(dev)?fs)$/) ||
+                                ($1 == "none") ||
+                                ($1 ~ /^(rootfs|\/dev\/root)$/) ||
+                                ($3 == "/"))
                            print $3
                        }' | sort | uniq`"
 for x in `awk '{ print $2 }' /proc/mounts | sort -r | uniq`
 do
 	do_unmount="yes"
+
+	# Do not umount these if we are booting off a livecd
+	if [ -n "${CDBOOT}" ] && \
+	   [ "${x}" = "/mnt/cdrom" -o "${x}" = "/mnt/livecd" ]
+	then
+		continue
+	fi
 	
-	for y in ${no_unmount}
+	for y in ${no_unmounts}
 	do
 		[ "${x}" = "${y}" ] && do_unmount="no"
 	done
 	
-	if [ "${do_unmount}" = "yes" ] && \
-	   [ "${x}" != "/" -a "${x}" != "/dev" -a "${x}" != "/proc" -a \
-	     "${x}" != "/sys" -a "${x}" != "/mnt/livecd" ]
+	if [ "${do_unmount}" = "yes" ]
 	then
-		umount -f ${x} &>/dev/null || {
+		umount ${x} &>/dev/null || {
 		
 			# Kill processes still using this mount
 			/bin/fuser -k -m -9 "${x}" &>/dev/null
@@ -132,9 +150,9 @@ mount_readonly() {
 	local x=
 	local retval=0
 	
-	for x in `awk '{ print $2 }' /proc/mounts`
+	for x in `awk '$1 != "none" { print $2 }' /proc/mounts | sort -r`
 	do
-		mount -n -f -o remount,ro ${x} &>/dev/null
+		mount -n -o remount,ro ${x} &>/dev/null
 		retval=$((${retval} + $?))
 	done
 
