@@ -2,7 +2,7 @@
 # Copyright 1999-2003 Gentoo Technologies, Inc.
 # Distributed under the terms of the GNU General Public License v2
 # Author:  Martin Schlemmer <azarah@gentoo.org>
-# $Header: /home/cvsroot/gentoo-src/rc-scripts/sbin/depscan.sh,v 1.20 2003/05/12 21:23:05 azarah Exp $
+# $Header: /home/cvsroot/gentoo-src/rc-scripts/sbin/depscan.sh,v 1.23 2004/02/08 11:42:21 azarah Exp $
 
 source /etc/init.d/functions.sh
 
@@ -10,7 +10,7 @@ ebegin "Caching service dependencies"
 
 if [ ! -d "${svcdir}" ]
 then
-	if ! install -d -m0755 "${svcdir}" 2>/dev/null
+	if ! mkdir -p -m 0755 "${svcdir}" 2>/dev/null
 	then
 		eerror " Could not create needed directory '${svcdir}'!"
 	fi
@@ -20,7 +20,7 @@ for x in ${svcdir} softscripts snapshot options started
 do
 	if [ ! -d "${x}" ]
 	then
-		if ! install -d -m0755 "${svcdir}/${x}" 2>/dev/null
+		if ! mkdir -p -m 0755 "${svcdir}/${x}" 2>/dev/null
 		then
 			eerror " Could not create needed directory '${svcdir}/${x}'!"
 		fi
@@ -28,31 +28,32 @@ do
 done
 
 # Clean out the non volitile directories ...
-rm -rf ${svcdir}/{broken,snapshot}/*
+rm -rf ${svcdir}/dep{cache,tree} ${svcdir}/{broken,snapshot}/*
+
+retval=0
+SVCDIR="${svcdir}"
+DEPTYPES="${deptypes}"
+ORDTYPES="${ordtypes}"
+
+export SVCDIR DEPTYPES ORDTYPES
 
 cd /etc/init.d
 
-if [ "${RC_DEBUG}" = "yes" ]
-then
-	/bin/gawk -v SVCDIR="${svcdir}" \
-		-f /lib/rcscripts/awk/functions.awk \
-		-f /lib/rcscripts/awk/cachedepends.awk \
-		> "${svcdir}/depcache"
-fi
-
-/bin/gawk -v SVCDIR="${svcdir}" \
+/bin/gawk \
 	-f /lib/rcscripts/awk/functions.awk \
-	-f /lib/rcscripts/awk/cachedepends.awk \
-\
-| bash | \
-\
-/bin/gawk -v SVCDIR="${svcdir}" \
-	-v DEPTYPES="${deptypes}" \
-	-v ORDTYPES="${ordtypes}" \
-	-f /lib/rcscripts/awk/functions.awk \
-	-f /lib/rcscripts/awk/gendepends.awk
+	-f /lib/rcscripts/awk/cachedepends.awk || \
+	retval=1
 
-eend $? "Failed to cache service dependencies"
+bash "${svcdir}/depcache" | \
+\
+/bin/gawk \
+	-f /lib/rcscripts/awk/functions.awk \
+	-f /lib/rcscripts/awk/gendepends.awk || \
+	retval=1
+
+eend ${retval} "Failed to cache service dependencies"
+
+exit ${retval}
 
 
 # vim:ts=4
