@@ -1,6 +1,6 @@
 # Copyright 1999-2003 Gentoo Technologies, Inc.
 # Distributed under the terms of the GNU General Public License v2
-# $Header: /home/cvsroot/gentoo-src/rc-scripts/sbin/functions.sh,v 1.47 2003/10/26 17:48:23 azarah Exp $
+# $Header: /home/cvsroot/gentoo-src/rc-scripts/sbin/functions.sh,v 1.48 2004/02/08 11:42:21 azarah Exp $
 
 
 RC_GOT_FUNCTIONS="yes"
@@ -699,7 +699,7 @@ save_options() {
 	shift
 	if [ ! -d "${svcdir}/options/${myservice}" ]
 	then
-		install -d -m0755 "${svcdir}/options/${myservice}"
+		mkdir -p -m 0755 "${svcdir}/options/${myservice}"
 	fi
 	
 	echo "$*" > "${svcdir}/options/${myservice}/${myopts}"
